==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/ListActionBase.java <==
package de.fzj.unicore.ucc.actions;

import org.apache.commons.cli.OptionBuilder;

import de.fzj.unicore.ucc.util.Filter;
import de.fzj.unicore.ucc.util.PropertyFilter;
import de.fzj.unicore.wsrflite.xmlbeans.client.BaseWSRFClient;

/**
 * Base class for actions creating a listing.<br/>
 * 
 * It supports filtering the resulting list.
 * 
 * @author schuller
 */
public abstract class ListActionBase<T extends BaseWSRFClient> extends ActionBase {
	
	protected boolean detailed;
	
	protected boolean all;
	
	protected boolean doFilter;
	
	protected Filter filter;
	
	//for unit testing
	protected static int lastNumberOfResults;
	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_FILTER_LONG)
				.withDescription("Filter the list")
				.isRequired(false)
				.hasArgs()
				.create(OPT_FILTER)
			);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_DETAILED_LONG)
				.withDescription("Detailed output")
				.isRequired(false)
				.create(OPT_DETAILED)
			);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_ALL_LONG)
				.withDescription("Print all properties")
				.isRequired(false)
				.create(OPT_ALL)
			);
		
	}

	@Override
	public void process() {
		super.process();
		lastNumberOfResults=0;
		doFilter=getCommandLine().hasOption(OPT_FILTER);
		verbose("Filtering = "+doFilter);
		detailed=getBooleanOption(OPT_DETAILED_LONG, OPT_DETAILED);
		verbose("Detailed listing = "+detailed);
		all=getBooleanOption(OPT_ALL_LONG, OPT_ALL);
		verbose("Printing WSRF properties = "+all);
		
		if(doFilter){
			filter=createFilter(getCommandLine().getOptionValues(OPT_FILTER));
		}
	}

	
	/**
	 * print details about a list entry, the 
	 * default implementation returns an empty string
	 * 
	 * @param entry - the {@link BaseWSRFClient} for the current list entry
	 * @return
	 */
	protected String getDetails(T entry)throws Exception{
		return "";
	}

	
	/**
	 * print details about a list entry, the 
	 * default implementation prints the properties document
	 * 
	 * @param entry - the {@link BaseWSRFClient} for the current list entry
	 * @return
	 */
	protected void printWSRFProperties(T entry){
		if(all){
			try{
				message(entry.getResourcePropertyDocument());
			}
			catch(Exception e){
				error("Could not get resource properties!", e);
				endProcessing(ERROR);
			}
		}
	}
	
	protected Filter createFilter(String[] args){
		filter=PropertyFilter.Factory.create(this, args);
		if(filter==null){
			verbose("Filtering parameters not understood --- not filtering.");
			doFilter=false;
		}
		return filter;
	}
	
	/**
	 * if filtering is enabled, the given resource is checked. 
	 * 
	 * @param resource
	 * @return true if the configured filter matches the resource 
	 */
	protected boolean filterMatch(T resource){
		if(!doFilter)return true;
		return filter.filterMatches(resource);
	}
	
	//for unit testing
	static int getLastNumberOfResults(){
		return lastNumberOfResults;
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/ListActionBase.java <==
package de.fzj.unicore.ucc.actions;

import org.apache.commons.cli.OptionBuilder;

import de.fzj.unicore.ucc.util.Filter;
import de.fzj.unicore.ucc.util.PropertyFilter;
import de.fzj.unicore.wsrflite.xmlbeans.client.BaseWSRFClient;

/**
 * Base class for actions creating a listing.<br/>
 * 
 * It supports filtering the resulting list.
 * 
 * @author schuller
 */
public abstract class ListActionBase<T extends BaseWSRFClient> extends ActionBase {
	
	protected boolean detailed;
	
	protected boolean all;
	
	protected boolean doFilter;
	
	protected Filter filter;
	
	//for unit testing
	protected static int lastNumberOfResults;
	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_FILTER_LONG)
				.withDescription("Filter the list")
				.isRequired(false)
				.hasArgs()
				.create(OPT_FILTER)
			);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_DETAILED_LONG)
				.withDescription("Detailed output")
				.isRequired(false)
				.create(OPT_DETAILED)
			);
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_ALL_LONG)
				.withDescription("Print all properties")
				.isRequired(false)
				.create(OPT_ALL)
			);
		
	}

	@Override
	public void process() {
		super.process();
		lastNumberOfResults=0;
		doFilter=getCommandLine().hasOption(OPT_FILTER);
		verbose("Filtering = "+doFilter);
		detailed=getBooleanOption(OPT_DETAILED_LONG, OPT_DETAILED);
		verbose("Detailed listing = "+detailed);
		all=getBooleanOption(OPT_ALL_LONG, OPT_ALL);
		verbose("Printing WSRF properties = "+all);
		
		if(doFilter){
			filter=createFilter(getCommandLine().getOptionValues(OPT_FILTER));
		}
	}

	
	/**
	 * Print details about a list entry.</br> 
	 * The default implementation returns an empty string
	 * 
	 * @param entry - the {@link BaseWSRFClient} for the current list entry
	 */
	protected String getDetails(T entry)throws Exception{
		return "";
	}

	
	/**
	 * print details about a list entry, the 
	 * default implementation prints the properties document
	 * 
	 * @param entry - the {@link BaseWSRFClient} for the current list entry
	 */
	protected void printWSRFProperties(T entry){
		if(all){
			try{
				message(entry.getResourcePropertyDocument());
			}
			catch(Exception e){
				error("Could not get resource properties!", e);
				endProcessing(ERROR);
			}
		}
	}
	
	protected Filter createFilter(String[] args){
		filter=PropertyFilter.Factory.create(this, args);
		if(filter==null){
			verbose("Filtering parameters not understood --- not filtering.");
			doFilter=false;
		}
		return filter;
	}
	
	/**
	 * if filtering is enabled, the given resource is checked. 
	 * 
	 * @param resource
	 * @return true if the configured filter matches the resource 
	 */
	protected boolean filterMatch(T resource){
		if(!doFilter)return true;
		return filter.filterMatches(resource);
	}
	
	//for unit testing
	static int getLastNumberOfResults(){
		return lastNumberOfResults;
	}
}
